@@ -79,6 +79,7 @@ static store_t store[] = {
   { "compass_damping",  STORE_INT,    OFFSET(compass_damping) },
   { "cachelist_hide_found", STORE_BOOL, OFFSET(cachelist_hide_found) },
   { "cachelist_update", STORE_BOOL,   OFFSET(cachelist_update) },
+  { "disable_gcvote",   STORE_BOOL,   OFFSET(disable_gcvote) },
 #ifdef USE_MAEMO
   { "mmpoi_dontlaunch", STORE_BOOL,   OFFSET(mmpoi_dontlaunch) },
   { "cachelist_dss",    STORE_BOOL,   OFFSET(cachelist_disable_screensaver) },
@@ -132,6 +133,19 @@ char *gconf_restore_closed_name(appdata_t *appdata, char *filename) {
 void gconf_save_state(appdata_t *appdata) {
   int entries = 0;
 
+  /* free proxy settings */
+  if(appdata->proxy) {
+    proxy_t *proxy = appdata->proxy;
+
+    if(proxy->authentication_password) g_free(proxy->authentication_password);
+    if(proxy->authentication_user)     g_free(proxy->authentication_user);
+    if(proxy->host)                    g_free(proxy->host);
+    if(proxy->ignore_hosts)            g_free(proxy->ignore_hosts);
+
+    g_free(proxy);
+    appdata->proxy = NULL;
+  }
+
   gpx_t *gpx = appdata->gpx;
   while(gpx) {
     char str[128];
@@ -207,6 +221,35 @@ void gconf_load_state(appdata_t *appdata) {
   appdata->manual_goto.lat = appdata->manual_goto.lon = NAN;
   appdata->gps.lat = appdata->gps.lon = NAN;
 
+  /* ------------- get proxy settings -------------------- */
+  if(gconf_client_get_bool(appdata->gconf_client, 
+			   PROXY_KEY "use_http_proxy", NULL)) {
+    proxy_t *proxy = appdata->proxy = g_new0(proxy_t, 1);
+    
+    /* get basic settings */
+    proxy->host = gconf_client_get_string(appdata->gconf_client, 
+					  PROXY_KEY "host", NULL);
+    proxy->port = gconf_client_get_int(appdata->gconf_client, 
+				       PROXY_KEY "port", NULL);
+    proxy->ignore_hosts =
+      gconf_client_get_string(appdata->gconf_client, 
+			      PROXY_KEY "ignore_hosts", NULL);
+    
+    /* check for authentication */
+    proxy->use_authentication =
+      gconf_client_get_bool(appdata->gconf_client, 
+			    PROXY_KEY "use_authentication", NULL);
+    
+    if(proxy->use_authentication) {
+      proxy->authentication_user =
+	gconf_client_get_string(appdata->gconf_client, 
+				PROXY_KEY "authentication_user", NULL);
+      proxy->authentication_password =
+	gconf_client_get_string(appdata->gconf_client, 
+				PROXY_KEY "authentication_password", NULL);
+    }
+  }
+
   int i, entries = gconf_client_get_int(appdata->gconf_client, 
 				 GCONF_KEY_CNT, NULL);
 
