@@ -22,6 +22,10 @@
 
 typedef enum { MAP_NONE=0, MAP_ALL, MAP_GPX, MAP_CACHE } map_state_t;
 
+typedef struct {
+  char *id;
+} cache_display_t;
+
 typedef struct map_context_s {
   appdata_t *appdata;
   GtkWidget *window;
@@ -32,6 +36,9 @@ typedef struct map_context_s {
   map_state_t state;
   void *cb_id;
 
+  int cache_list_len;
+  cache_display_t *caches_displayed;
+
 #if MAEMO_VERSION_MAJOR == 5
   GtkWidget *old_view;
 #endif
