@@ -499,3 +499,13 @@ GtkWidget *link_icon_button_by_id(appdata_t *appdata, GtkWidget *icon,
   return icon;
 }
 
+/* left aligned, word wrapped multiline widget */
+GtkWidget *simple_text_widget(char *text) {
+  GtkWidget *label = gtk_label_new(text);
+  
+  gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
+  gtk_label_set_line_wrap_mode(GTK_LABEL(label), PANGO_WRAP_WORD);
+  gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+
+  return label;
+}
